@@ -2,6 +2,12 @@ import os,tempfile,multiprocessing as mp
 import numpy as np,pandas as pd
 from tqdm import tqdm
 
+# default num proc is?
+DEFAULT_NUM_PROC = mp.cpu_count() - 1
+
+# boost to max if just 2? (hack for google colab/cloud context)
+if mp.cpu_count()==2: DEFAULT_NUM_PROC=2
+
 
 def pmap_iter(func, objs, args=[], kwargs={}, num_proc=DEFAULT_NUM_PROC, use_threads=False, progress=True, desc=None, **y):
 	"""
@@ -64,7 +70,7 @@ def pmap_df(df, func, num_proc=DEFAULT_NUM_PROC):
 	return df
 
 
-def pmap_groups(func,df_grouped,use_cache=True,num_proc=DEFAULT_NUM_PROC,**attrs):
+def pmap_groups(func,df_grouped,use_cache=False,num_proc=DEFAULT_NUM_PROC,**attrs):
 
 
 	# get index/groupby col name(s)
